@@ -20,6 +20,7 @@
 
 /**
  * SECTION:gestrack
+ * @title: GESTrack
  * @short_description: Composition of objects
  *
  * Corresponds to one output format (i.e. audio OR video).
@@ -640,8 +641,8 @@ ges_track_class_init (GESTrackClass * klass)
   g_object_class_install_property (object_class, ARG_MIXING,
       properties[ARG_MIXING]);
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&ges_track_src_pad_template));
+  gst_element_class_add_static_pad_template (gstelement_class,
+      &ges_track_src_pad_template);
 
   /**
    * GESTrack::track-element-added:
@@ -711,7 +712,7 @@ ges_track_init (GESTrack * self)
  * The newly created track will steal a reference to the caps. If you wish to
  * use those caps elsewhere, you will have to take an extra reference.
  *
- * Returns: A new #GESTrack.
+ * Returns: (transfer floating): A new #GESTrack.
  */
 GESTrack *
 ges_track_new (GESTrackType type, GstCaps * caps)
@@ -911,7 +912,7 @@ ges_track_set_mixing (GESTrack * track, gboolean mixing)
 /**
  * ges_track_add_element:
  * @track: a #GESTrack
- * @object: (transfer full): the #GESTrackElement to add
+ * @object: (transfer floating): the #GESTrackElement to add
  *
  * Adds the given object to the track. Sets the object's controlling track,
  * and thus takes ownership of the @object.
@@ -931,11 +932,15 @@ ges_track_add_element (GESTrack * track, GESTrackElement * object)
 
   if (G_UNLIKELY (ges_track_element_get_track (object) != NULL)) {
     GST_WARNING ("Object already belongs to another track");
+    gst_object_ref_sink (object);
+    gst_object_unref (object);
     return FALSE;
   }
 
   if (G_UNLIKELY (!ges_track_element_set_track (object, track))) {
     GST_ERROR ("Couldn't properly add the object to the Track");
+    gst_object_ref_sink (object);
+    gst_object_unref (object);
     return FALSE;
   }
 
@@ -946,6 +951,8 @@ ges_track_add_element (GESTrack * track, GESTrackElement * object)
   if (G_UNLIKELY (!ges_nle_composition_add_object (track->priv->composition,
               ges_track_element_get_nleobject (object)))) {
     GST_WARNING ("Couldn't add object to the NleComposition");
+    gst_object_ref_sink (object);
+    gst_object_unref (object);
     return FALSE;
   }
 
@@ -1059,7 +1066,7 @@ ges_track_get_caps (GESTrack * track)
  *
  * Get the #GESTimeline this track belongs to. Can be %NULL.
  *
- * Returns: The #GESTimeline this track belongs to. Can be %NULL.
+ * Returns: (nullable): The #GESTimeline this track belongs to. Can be %NULL.
  */
 const GESTimeline *
 ges_track_get_timeline (GESTrack * track)
